pub struct StoreMediaParams {
pub filename: String,
pub data: Option<String>,
pub url: Option<String>,
pub path: Option<String>,
pub delete_existing: Option<bool>,
}Expand description
Parameters for storing a media file.
Fields
filename: StringFilename to save as.
data: Option<String>Base64-encoded file data.
url: Option<String>URL to download from.
path: Option<String>Local file path.
delete_existing: Option<bool>Delete existing file with same name.
Implementations
Sourceimpl StoreMediaParams
impl StoreMediaParams
Sourcepub fn from_base64(
filename: impl Into<String>,
data: impl Into<String>,
) -> StoreMediaParams
pub fn from_base64( filename: impl Into<String>, data: impl Into<String>, ) -> StoreMediaParams
Create params for storing base64-encoded data.
Sourcepub fn from_url(
filename: impl Into<String>,
url: impl Into<String>,
) -> StoreMediaParams
pub fn from_url( filename: impl Into<String>, url: impl Into<String>, ) -> StoreMediaParams
Create params for storing from a URL.
Sourcepub fn from_path(
filename: impl Into<String>,
path: impl Into<String>,
) -> StoreMediaParams
pub fn from_path( filename: impl Into<String>, path: impl Into<String>, ) -> StoreMediaParams
Create params for storing from a local file path.
Sourcepub fn delete_existing(self, delete: bool) -> StoreMediaParams
pub fn delete_existing(self, delete: bool) -> StoreMediaParams
Set whether to delete existing file with same name.